////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  video_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "video_1_0_0.h"
#include "parametersetmanager.h"

VIDEO_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "general") == 0)
    {
        __result = general.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "fusion") == 0)
    {
        __result = fusion.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "sat") == 0)
    {
        __result = sat.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_video10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "general") == 0)
    {
        __result = general.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "fusion") == 0)
    {
        __result = fusion.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "sat") == 0)
    {
        __result = sat.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_video10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // general
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("general", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "general") == 0)
    {
        __result = general.GetInfo(&__path[__pos], __info);
    }

    // fusion
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fusion", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "fusion") == 0)
    {
        __result = fusion.GetInfo(&__path[__pos], __info);
    }

    // sat
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sat", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "sat") == 0)
    {
        __result = sat.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_param_1") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_1, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_2") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_2, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_3") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_3, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_4") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_4, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_5") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_5, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_param_6") == 0)
    {
        ParameterUtils::DoubleToString((double)res_param_6, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_1_tab") == 0)
    {
        __result = res_lut_param_1_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_2_tab") == 0)
    {
        __result = res_lut_param_2_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_3_tab") == 0)
    {
        __result = res_lut_param_3_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_param_1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_2") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_2 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_3") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_3 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_4") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_4 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_5") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_5 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_param_6") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            res_param_6 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_1_tab") == 0)
    {
        __result = res_lut_param_1_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_2_tab") == 0)
    {
        __result = res_lut_param_2_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_3_tab") == 0)
    {
        __result = res_lut_param_3_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_param_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_1", ParameterParserDataType::Float, (double)res_param_1));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_1));
    }

    // res_param_2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_2", ParameterParserDataType::Float, (double)res_param_2));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_2") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_2));
    }

    // res_param_3
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_3", ParameterParserDataType::Float, (double)res_param_3));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_3") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_3));
    }

    // res_param_4
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_4", ParameterParserDataType::Float, (double)res_param_4));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_4") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_4));
    }

    // res_param_5
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_5", ParameterParserDataType::Float, (double)res_param_5));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_5") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_5));
    }

    // res_param_6
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_param_6", ParameterParserDataType::Float, (double)res_param_6));
    }
    else if (PARAMETER_STRCMP(__name, "res_param_6") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)res_param_6));
    }

    // res_lut_param_1_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_1_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_1_tab") == 0)
    {
        __result = res_lut_param_1_tab.GetInfo(&__path[__pos], __info);
    }

    // res_lut_param_2_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_2_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_2_tab") == 0)
    {
        __result = res_lut_param_2_tab.GetInfo(&__path[__pos], __info);
    }

    // res_lut_param_3_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_3_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "res_lut_param_3_tab") == 0)
    {
        __result = res_lut_param_3_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_1_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_1") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_1[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_1[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_1_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_1") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_1[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_1[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_1_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_1", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_2_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_2") == 0)
    {
        if (__index < 32)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_2[__index], __value, __size);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 32; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_2[i], &__value[__valuePos], (INT32)(__size - __valuePos));
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_2_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_2") == 0)
    {
        if (__index < 32)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_2[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 32)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_2[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_2_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_2", ParameterParserDataType::Float, true, false, 32));
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_3_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_3") == 0)
    {
        if (__index < 16)
        {
            ParameterUtils::DoubleToString((double)res_lut_param_3[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 16; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)res_lut_param_3[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_3_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "res_lut_param_3") == 0)
    {
        if (__index < 16)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                res_lut_param_3[__index] = (UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 16)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    res_lut_param_3[__index] = (UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::generalStruct::res_lut_param_3_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // res_lut_param_3
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("res_lut_param_3", ParameterParserDataType::UInt32, true, false, 16));
    }

    return __result;
}

bool chromatix_video10_reserveType::fusionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mode") == 0)
    {
        ParameterUtils::DoubleToString((double)mode, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_video10_reserveType::fusionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            mode = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::fusionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mode", ParameterParserDataType::UInt32, (double)mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)mode, 0));
    }

    return __result;
}

bool chromatix_video10_reserveType::satStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sat_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)sat_enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "min_margin_ratio") == 0)
    {
        ParameterUtils::DoubleToString((double)min_margin_ratio, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_margin_ratio") == 0)
    {
        ParameterUtils::DoubleToString((double)max_margin_ratio, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dz_for_max_margin_ratio") == 0)
    {
        ParameterUtils::DoubleToString((double)dz_for_max_margin_ratio, __value, __size);
        __result = true;
    }

    return __result;
}

bool chromatix_video10_reserveType::satStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "sat_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            sat_enable = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "min_margin_ratio") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            min_margin_ratio = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_margin_ratio") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_margin_ratio = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dz_for_max_margin_ratio") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dz_for_max_margin_ratio = (float)dblValue; 
        }
    }

    return __result;
}

bool chromatix_video10_reserveType::satStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // sat_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("sat_enable", ParameterParserDataType::UInt32, (double)sat_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "sat_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)sat_enable, 0));
    }

    // min_margin_ratio
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_margin_ratio", ParameterParserDataType::Float, (double)min_margin_ratio));
    }
    else if (PARAMETER_STRCMP(__name, "min_margin_ratio") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)min_margin_ratio));
    }

    // max_margin_ratio
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_margin_ratio", ParameterParserDataType::Float, (double)max_margin_ratio));
    }
    else if (PARAMETER_STRCMP(__name, "max_margin_ratio") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)max_margin_ratio));
    }

    // dz_for_max_margin_ratio
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dz_for_max_margin_ratio", ParameterParserDataType::Float, (double)dz_for_max_margin_ratio));
    }
    else if (PARAMETER_STRCMP(__name, "dz_for_max_margin_ratio") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dz_for_max_margin_ratio));
    }

    return __result;
}

bool video10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "general") == 0)
    {
        __result = general.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "fusion") == 0)
    {
        __result = fusion.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool video10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "general") == 0)
    {
        __result = general.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "fusion") == 0)
    {
        __result = fusion.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool video10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // general
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("general", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "general") == 0)
    {
        __result = general.GetInfo(&__path[__pos], __info);
    }

    // fusion
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("fusion", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "fusion") == 0)
    {
        __result = fusion.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool video10_rgn_dataType::generalStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "max_vsr") == 0)
    {
        ParameterUtils::DoubleToString((double)max_vsr, __value, __size);
        __result = true;
    }

    return __result;
}

bool video10_rgn_dataType::generalStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "max_vsr") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_vsr = (float)dblValue; 
        }
    }

    return __result;
}

bool video10_rgn_dataType::generalStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // max_vsr
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_vsr", ParameterParserDataType::Float, (double)max_vsr));
    }
    else if (PARAMETER_STRCMP(__name, "max_vsr") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)max_vsr));
    }

    return __result;
}

bool video10_rgn_dataType::fusionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "image_conf_high_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)image_conf_high_threshold, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "image_conf_low_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)image_conf_low_threshold, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "absolute_motion_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)absolute_motion_threshold, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "absolute_motion_confidence_threshold") == 0)
    {
        ParameterUtils::DoubleToString((double)absolute_motion_confidence_threshold, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "min_age") == 0)
    {
        ParameterUtils::DoubleToString((double)min_age, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool video10_rgn_dataType::fusionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "image_conf_high_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            image_conf_high_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "image_conf_low_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            image_conf_low_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "absolute_motion_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            absolute_motion_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "absolute_motion_confidence_threshold") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            absolute_motion_confidence_threshold = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "min_age") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            min_age = (float)dblValue; 
        }
    }

    return __result;
}

bool video10_rgn_dataType::fusionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // image_conf_high_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("image_conf_high_threshold", ParameterParserDataType::Int32, (double)image_conf_high_threshold, 0));
    }
    else if (PARAMETER_STRCMP(__name, "image_conf_high_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)image_conf_high_threshold, 0));
    }

    // image_conf_low_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("image_conf_low_threshold", ParameterParserDataType::Int32, (double)image_conf_low_threshold, 0));
    }
    else if (PARAMETER_STRCMP(__name, "image_conf_low_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)image_conf_low_threshold, 0));
    }

    // absolute_motion_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("absolute_motion_threshold", ParameterParserDataType::Float, (double)absolute_motion_threshold));
    }
    else if (PARAMETER_STRCMP(__name, "absolute_motion_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)absolute_motion_threshold));
    }

    // absolute_motion_confidence_threshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("absolute_motion_confidence_threshold", ParameterParserDataType::UInt32, (double)absolute_motion_confidence_threshold, 0));
    }
    else if (PARAMETER_STRCMP(__name, "absolute_motion_confidence_threshold") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)absolute_motion_confidence_threshold, 0));
    }

    // min_age
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_age", ParameterParserDataType::UInt32, (double)min_age, 0));
    }
    else if (PARAMETER_STRCMP(__name, "min_age") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)min_age, 0));
    }

    return __result;
}

bool mod_video10_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "video10_rgn_data") == 0)
    {
        __result = video10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_video10_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "video10_rgn_data") == 0)
    {
        __result = video10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_video10_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // video10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("video10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "video10_rgn_data") == 0)
    {
        __result = video10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_video10_pre_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_video10_pre_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_video10_pre_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // pre_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // pre_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_scale_ratio_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_video10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_aec_data") == 0)
    {
        if (__index < mod_video10_aec_dataCount)
        {
            __result = mod_video10_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_video10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_aec_data") == 0)
    {
        if (__index < mod_video10_aec_dataCount)
        {
            __result = mod_video10_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_video10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_video10_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_video10_aec_data", ParameterParserDataType::Structure, true, false, mod_video10_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_video10_aec_data") == 0)
    {
        if (__index < mod_video10_aec_dataCount)
        {
            __result = mod_video10_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_video10_aec_dataCount));
        }
    }

    return __result;
}

bool mod_video10_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_video10_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_video10_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_video10_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_video10_pre_scale_ratio_dataCount)
        {
            __result = mod_video10_pre_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_video10_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_video10_pre_scale_ratio_dataCount)
        {
            __result = mod_video10_pre_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_video10_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_video10_pre_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_video10_pre_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_video10_pre_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_video10_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_video10_pre_scale_ratio_dataCount)
        {
            __result = mod_video10_pre_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_video10_pre_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool mod_video10_lens_zoom_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_video10_lens_zoom_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_video10_lens_zoom_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lens_zoom_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_zoom_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_trigger") == 0)
    {
        __result = lens_zoom_trigger.GetInfo(&__path[__pos], __info);
    }

    // lens_zoom_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_zoom_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_zoom_data") == 0)
    {
        __result = lens_zoom_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_video10_lens_zoom_dataType::lens_zoom_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_hdr_aec_data") == 0)
    {
        if (__index < mod_video10_hdr_aec_dataCount)
        {
            __result = mod_video10_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_video10_lens_zoom_dataType::lens_zoom_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_hdr_aec_data") == 0)
    {
        if (__index < mod_video10_hdr_aec_dataCount)
        {
            __result = mod_video10_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_video10_lens_zoom_dataType::lens_zoom_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_video10_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_video10_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_video10_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_video10_hdr_aec_data") == 0)
    {
        if (__index < mod_video10_hdr_aec_dataCount)
        {
            __result = mod_video10_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_video10_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool mod_video10_lens_posn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_video10_lens_posn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_video10_lens_posn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // lens_posn_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_posn_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_trigger") == 0)
    {
        __result = lens_posn_trigger.GetInfo(&__path[__pos], __info);
    }

    // lens_posn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lens_posn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "lens_posn_data") == 0)
    {
        __result = lens_posn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_video10_lens_posn_dataType::lens_posn_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_lens_zoom_data") == 0)
    {
        if (__index < mod_video10_lens_zoom_dataCount)
        {
            __result = mod_video10_lens_zoom_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_video10_lens_posn_dataType::lens_posn_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_lens_zoom_data") == 0)
    {
        if (__index < mod_video10_lens_zoom_dataCount)
        {
            __result = mod_video10_lens_zoom_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_video10_lens_posn_dataType::lens_posn_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_video10_lens_zoom_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_video10_lens_zoom_data", ParameterParserDataType::Structure, true, false, mod_video10_lens_zoom_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_video10_lens_zoom_data") == 0)
    {
        if (__index < mod_video10_lens_zoom_dataCount)
        {
            __result = mod_video10_lens_zoom_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_video10_lens_zoom_dataCount));
        }
    }

    return __result;
}

bool chromatix_video10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_lens_posn_data") == 0)
    {
        if (__index < mod_video10_lens_posn_dataCount)
        {
            __result = mod_video10_lens_posn_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_video10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_video10_lens_posn_data") == 0)
    {
        if (__index < mod_video10_lens_posn_dataCount)
        {
            __result = mod_video10_lens_posn_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_video10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_video10_lens_posn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_video10_lens_posn_data", ParameterParserDataType::Structure, true, false, mod_video10_lens_posn_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_video10_lens_posn_data") == 0)
    {
        if (__index < mod_video10_lens_posn_dataCount)
        {
            __result = mod_video10_lens_posn_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_video10_lens_posn_dataCount));
        }
    }

    return __result;
}

bool chromatix_video10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_video10_reserve") == 0)
    {
        __result = chromatix_video10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_video10_core") == 0)
    {
        __result = chromatix_video10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_video10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_video10_reserve") == 0)
    {
        __result = chromatix_video10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_video10_core") == 0)
    {
        __result = chromatix_video10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_video10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_video10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_video10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_video10_reserve") == 0)
    {
        __result = chromatix_video10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_video10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_video10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_video10_core") == 0)
    {
        __result = chromatix_video10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_video10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_video10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_video10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_video10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_video10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_video10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_video10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 5)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 5; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 5)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 5)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_video10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 5));
    }

    return __result;
}

bool chromatix_video10Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_video10Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_video10Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_video10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_lens_position):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_lens_position;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_lens_zoom):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_lens_zoom;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_pre_scale_ratio):
            enumValue = chromatix_video10Type::control_variablesStruct::control_var_typeEnum::control_pre_scale_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_video10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_video10TypeClass::chromatix_video10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_video10_reserve);
    PARAMETER_INITIALIZE(chromatix_video10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_video10TypeClass::chromatix_video10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_video10_reserve);
    PARAMETER_INITIALIZE(chromatix_video10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_video10TypeClass::~chromatix_video10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_video10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "video10_sw")) == 0)
    {
        name = "video10_sw";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(general);
    PARAMETER_INITIALIZE(fusion);
    PARAMETER_INITIALIZE(sat);

    result = general.Load(entry, alignment);
    if (result)
    {
        result = fusion.Load(entry, alignment);
    }
    if (result)
    {
        result = sat.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType_generalStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::generalStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_param_1);
    PARAMETER_INITIALIZE(res_param_2);
    PARAMETER_INITIALIZE(res_param_3);
    PARAMETER_INITIALIZE(res_param_4);
    PARAMETER_INITIALIZE(res_param_5);
    PARAMETER_INITIALIZE(res_param_6);
    PARAMETER_INITIALIZE(res_lut_param_1_tab);
    PARAMETER_INITIALIZE(res_lut_param_2_tab);
    PARAMETER_INITIALIZE(res_lut_param_3_tab);

    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_2, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_3, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_4, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_5, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, res_param_6, alignment)
    if (result)
    {
        result = res_lut_param_1_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = res_lut_param_2_tab.Load(entry, alignment);
    }
    if (result)
    {
        result = res_lut_param_3_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType_generalStruct_res_lut_param_1_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::generalStruct::res_lut_param_1_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_1);

    result = entry->ReadArray(res_lut_param_1, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType_generalStruct_res_lut_param_2_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::generalStruct::res_lut_param_2_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_2);

    result = entry->ReadArray(res_lut_param_2, 32, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType_generalStruct_res_lut_param_3_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::generalStruct::res_lut_param_3_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(res_lut_param_3);

    result = entry->ReadArray(res_lut_param_3, 16, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType_fusionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::fusionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mode);

    SYMBOL_TABLE_ENTRY_READ(entry, result, mode, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_reserveType_satStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_reserveType::satStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(sat_enable);
    PARAMETER_INITIALIZE(min_margin_ratio);
    PARAMETER_INITIALIZE(max_margin_ratio);
    PARAMETER_INITIALIZE(dz_for_max_margin_ratio);

    SYMBOL_TABLE_ENTRY_READ(entry, result, sat_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, min_margin_ratio, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_margin_ratio, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dz_for_max_margin_ratio, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load video10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool video10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(general);
    PARAMETER_INITIALIZE(fusion);

    result = general.Load(entry, alignment);
    if (result)
    {
        result = fusion.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load video10_rgn_dataType_generalStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool video10_rgn_dataType::generalStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(max_vsr);

    SYMBOL_TABLE_ENTRY_READ(entry, result, max_vsr, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load video10_rgn_dataType_fusionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool video10_rgn_dataType::fusionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(image_conf_high_threshold);
    PARAMETER_INITIALIZE(image_conf_low_threshold);
    PARAMETER_INITIALIZE(absolute_motion_threshold);
    PARAMETER_INITIALIZE(absolute_motion_confidence_threshold);
    PARAMETER_INITIALIZE(min_age);

    SYMBOL_TABLE_ENTRY_READ(entry, result, image_conf_high_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, image_conf_low_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, absolute_motion_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, absolute_motion_confidence_threshold, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, min_age, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(video10_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = video10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_pre_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_pre_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(pre_scale_ratio_trigger);
    PARAMETER_INITIALIZE(pre_scale_ratio_data);

    result = pre_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = pre_scale_ratio_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_pre_scale_ratio_dataType_pre_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_video10_aec_data);


    // Reading Array mod_video10_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_video10_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_video10_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_video10_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_video10_aec_dataDupInfo = pointerEntry->GetDupObject(mod_video10_aec_dataCount, file, line);
            if (mod_video10_aec_dataDupInfo != nullptr && mod_video10_aec_dataDupInfo->Object != nullptr)
            {
                mod_video10_aec_data = (mod_video10_aec_dataType*)mod_video10_aec_dataDupInfo->Object;
                if (mod_video10_aec_data == nullptr)
                {
                    if (mod_video10_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_video10_aec_dataDupInfo->File, mod_video10_aec_dataDupInfo->Line, mod_video10_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_video10_aec_dataDupInfo->Line, mod_video10_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_video10_aec_data == nullptr)
            {
                if (result && mod_video10_aec_dataCount > 0)
                {
                    mod_video10_aec_data = PARAMETER_NEW mod_video10_aec_dataType[mod_video10_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_video10_aec_data, mod_video10_aec_dataCount, file, line);
                }
                if (!result || mod_video10_aec_data == nullptr)
                {
                    if (mod_video10_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_video10_aec_data\n");
                    }
                    mod_video10_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_video10_aec_dataCount; i++)
                {
                    result = mod_video10_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_video10_aec_data == nullptr)
        {
            mod_video10_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_video10_pre_scale_ratio_data);


    // Reading Array mod_video10_pre_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_video10_pre_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_video10_pre_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_video10_pre_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_video10_pre_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_video10_pre_scale_ratio_dataCount, file, line);
            if (mod_video10_pre_scale_ratio_dataDupInfo != nullptr && mod_video10_pre_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_video10_pre_scale_ratio_data = (mod_video10_pre_scale_ratio_dataType*)mod_video10_pre_scale_ratio_dataDupInfo->Object;
                if (mod_video10_pre_scale_ratio_data == nullptr)
                {
                    if (mod_video10_pre_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_pre_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_video10_pre_scale_ratio_dataDupInfo->File, mod_video10_pre_scale_ratio_dataDupInfo->Line, mod_video10_pre_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_pre_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_video10_pre_scale_ratio_dataDupInfo->Line, mod_video10_pre_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_video10_pre_scale_ratio_data == nullptr)
            {
                if (result && mod_video10_pre_scale_ratio_dataCount > 0)
                {
                    mod_video10_pre_scale_ratio_data = PARAMETER_NEW mod_video10_pre_scale_ratio_dataType[mod_video10_pre_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_video10_pre_scale_ratio_data, mod_video10_pre_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_video10_pre_scale_ratio_data == nullptr)
                {
                    if (mod_video10_pre_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_video10_pre_scale_ratio_data\n");
                    }
                    mod_video10_pre_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_video10_pre_scale_ratio_dataCount; i++)
                {
                    result = mod_video10_pre_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_video10_pre_scale_ratio_data == nullptr)
        {
            mod_video10_pre_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_lens_zoom_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_lens_zoom_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lens_zoom_trigger);
    PARAMETER_INITIALIZE(lens_zoom_data);

    result = lens_zoom_trigger.Load(entry, alignment);
    if (result)
    {
        result = lens_zoom_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_lens_zoom_dataType_lens_zoom_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_lens_zoom_dataType::lens_zoom_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_video10_hdr_aec_data);


    // Reading Array mod_video10_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_video10_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_video10_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_video10_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_video10_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_video10_hdr_aec_dataCount, file, line);
            if (mod_video10_hdr_aec_dataDupInfo != nullptr && mod_video10_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_video10_hdr_aec_data = (mod_video10_hdr_aec_dataType*)mod_video10_hdr_aec_dataDupInfo->Object;
                if (mod_video10_hdr_aec_data == nullptr)
                {
                    if (mod_video10_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_video10_hdr_aec_dataDupInfo->File, mod_video10_hdr_aec_dataDupInfo->Line, mod_video10_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_video10_hdr_aec_dataDupInfo->Line, mod_video10_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_video10_hdr_aec_data == nullptr)
            {
                if (result && mod_video10_hdr_aec_dataCount > 0)
                {
                    mod_video10_hdr_aec_data = PARAMETER_NEW mod_video10_hdr_aec_dataType[mod_video10_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_video10_hdr_aec_data, mod_video10_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_video10_hdr_aec_data == nullptr)
                {
                    if (mod_video10_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_video10_hdr_aec_data\n");
                    }
                    mod_video10_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_video10_hdr_aec_dataCount; i++)
                {
                    result = mod_video10_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_video10_hdr_aec_data == nullptr)
        {
            mod_video10_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_lens_posn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_lens_posn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(lens_posn_trigger);
    PARAMETER_INITIALIZE(lens_posn_data);

    result = lens_posn_trigger.Load(entry, alignment);
    if (result)
    {
        result = lens_posn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_video10_lens_posn_dataType_lens_posn_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_video10_lens_posn_dataType::lens_posn_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_video10_lens_zoom_data);


    // Reading Array mod_video10_lens_zoom_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_video10_lens_zoom_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_video10_lens_zoom_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_video10_lens_zoom_dataID = pointerEntry->ID;
            DupObjInfo* mod_video10_lens_zoom_dataDupInfo = pointerEntry->GetDupObject(mod_video10_lens_zoom_dataCount, file, line);
            if (mod_video10_lens_zoom_dataDupInfo != nullptr && mod_video10_lens_zoom_dataDupInfo->Object != nullptr)
            {
                mod_video10_lens_zoom_data = (mod_video10_lens_zoom_dataType*)mod_video10_lens_zoom_dataDupInfo->Object;
                if (mod_video10_lens_zoom_data == nullptr)
                {
                    if (mod_video10_lens_zoom_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_lens_zoom_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_video10_lens_zoom_dataDupInfo->File, mod_video10_lens_zoom_dataDupInfo->Line, mod_video10_lens_zoom_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_lens_zoom_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_video10_lens_zoom_dataDupInfo->Line, mod_video10_lens_zoom_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_video10_lens_zoom_data == nullptr)
            {
                if (result && mod_video10_lens_zoom_dataCount > 0)
                {
                    mod_video10_lens_zoom_data = PARAMETER_NEW mod_video10_lens_zoom_dataType[mod_video10_lens_zoom_dataCount];
                    (void)pointerEntry->SetDupObject(mod_video10_lens_zoom_data, mod_video10_lens_zoom_dataCount, file, line);
                }
                if (!result || mod_video10_lens_zoom_data == nullptr)
                {
                    if (mod_video10_lens_zoom_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_video10_lens_zoom_data\n");
                    }
                    mod_video10_lens_zoom_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_video10_lens_zoom_dataCount; i++)
                {
                    result = mod_video10_lens_zoom_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_video10_lens_zoom_data == nullptr)
        {
            mod_video10_lens_zoom_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_video10_lens_posn_data);


    // Reading Array mod_video10_lens_posn_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_video10_lens_posn_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_video10_lens_posn_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_video10_lens_posn_dataID = pointerEntry->ID;
            DupObjInfo* mod_video10_lens_posn_dataDupInfo = pointerEntry->GetDupObject(mod_video10_lens_posn_dataCount, file, line);
            if (mod_video10_lens_posn_dataDupInfo != nullptr && mod_video10_lens_posn_dataDupInfo->Object != nullptr)
            {
                mod_video10_lens_posn_data = (mod_video10_lens_posn_dataType*)mod_video10_lens_posn_dataDupInfo->Object;
                if (mod_video10_lens_posn_data == nullptr)
                {
                    if (mod_video10_lens_posn_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_lens_posn_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_video10_lens_posn_dataDupInfo->File, mod_video10_lens_posn_dataDupInfo->Line, mod_video10_lens_posn_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_video10_lens_posn_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_video10_lens_posn_dataDupInfo->Line, mod_video10_lens_posn_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_video10_lens_posn_data == nullptr)
            {
                if (result && mod_video10_lens_posn_dataCount > 0)
                {
                    mod_video10_lens_posn_data = PARAMETER_NEW mod_video10_lens_posn_dataType[mod_video10_lens_posn_dataCount];
                    (void)pointerEntry->SetDupObject(mod_video10_lens_posn_data, mod_video10_lens_posn_dataCount, file, line);
                }
                if (!result || mod_video10_lens_posn_data == nullptr)
                {
                    if (mod_video10_lens_posn_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_video10_lens_posn_data\n");
                    }
                    mod_video10_lens_posn_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_video10_lens_posn_dataCount; i++)
                {
                    result = mod_video10_lens_posn_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_video10_lens_posn_data == nullptr)
        {
            mod_video10_lens_posn_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_video10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_video10_reserve);
    PARAMETER_INITIALIZE(chromatix_video10_core);

    result = module_version.Load(entry, alignment);
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_video10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_video10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 5; i++)
    {
        result = chromatix_video10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_pre_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_pre_scale_ratio_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    pre_scale_ratio_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_pre_scale_ratio_dataType_pre_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_video10_aec_data))
    {
        PARAMETER_DELETE[] mod_video10_aec_data;
    }
    mod_video10_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_video10_pre_scale_ratio_dataCount; i++)
    {
        mod_video10_pre_scale_ratio_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_video10_pre_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_video10_pre_scale_ratio_data;
    }
    mod_video10_pre_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_lens_zoom_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_lens_zoom_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    lens_zoom_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_lens_zoom_dataType_lens_zoom_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_lens_zoom_dataType::lens_zoom_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_video10_hdr_aec_dataCount; i++)
    {
        mod_video10_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_video10_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_video10_hdr_aec_data;
    }
    mod_video10_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_lens_posn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_lens_posn_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    lens_posn_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_video10_lens_posn_dataType_lens_posn_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_video10_lens_posn_dataType::lens_posn_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_video10_lens_zoom_dataCount; i++)
    {
        mod_video10_lens_zoom_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_video10_lens_zoom_data))
    {
        PARAMETER_DELETE[] mod_video10_lens_zoom_data;
    }
    mod_video10_lens_zoom_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_video10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_video10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_video10_lens_posn_dataCount; i++)
    {
        mod_video10_lens_posn_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_video10_lens_posn_data))
    {
        PARAMETER_DELETE[] mod_video10_lens_posn_data;
    }
    mod_video10_lens_posn_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_video10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_video10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_video10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_video10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_video10Type::Release()
{
    ((chromatix_video10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_video10Type::GetModified()
{
    return ((chromatix_video10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_video10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_video10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_video10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_video10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_video10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_video10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_video10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_video10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_video10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_video10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_video10TypeClass::Release()
{
    ParameterModule::Release();
}

VIDEO_1_0_0_NAMESPACE_END
